# Welcome to vgrid

[![image](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/opengeoshub/vgrid/blob/master)
[![image](https://studiolab.sagemaker.aws/studiolab.svg)](https://studiolab.sagemaker.aws/import/github/opengeoshub/vgrid/blob/master/docs/notebooks/00_intro.ipynb)
[![image](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/opengeoshub/vgrid/HEAD)
[![image](https://img.shields.io/pypi/v/vgrid.svg)](https://pypi.python.org/pypi/vgrid)
[![image](https://static.pepy.tech/badge/vgrid)](https://pepy.tech/project/vgrid)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

[![logo](https://raw.githubusercontent.com/opengeoshub/vgridtools/refs/heads/main/images/vgrid_rect.svg)](https://github.com/opengeoshub/vgridtools/blob/main/images/vgrid512.svg)


**Vgrid - DGGS and Cell-based Geocoding Utilities**

-   GitHub repo: <https://github.com/opengeoshub/vgrid>
-   Documentation: <https://github.com/opengeoshub/vgrid>
-   PyPI: <https://pypi.org/project/vgrid>
-   Conda-forge: <https://anaconda.org/conda-forge/vgrid>
-   Free software: [MIT license](https://opensource.org/licenses/MIT)

Join our Discord server 👇

[![](https://dcbadge.limes.pink/api/server/https://discord.gg/narP4crb)](https://discord.gg/narP4crb)

## Introduction
[![vgrid](https://raw.githubusercontent.com/opengeoshub/vgridtools/main/images/readme/dggs.png)](https://github.com/opengeoshub/vgridtools/blob/main/images/readme/dggs.png)


**vgrid** 

## Acknowledgments

This doc  is inspired by ([leafmap](https://leafmap.org/)).

## Statement of Need


## Usage

Launch the interactive notebook tutorial for the **vgrid** Python package with Amazon SageMaker Studio Lab, Microsoft Planetary Computer, Google Colab, or Binder:

[![image](https://studiolab.sagemaker.aws/studiolab.svg)](https://studiolab.sagemaker.aws/import/github/opengeoshub/vgrid/blob/master/docs/notebooks/00_intro.ipynb)
[![image](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/opengeoshub/vgrid/blob/master)
[![image](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/opengeoshub/vgrid/HEAD)


## Key Features

- **DGGS Conversion:** Convert latlon to DGGS, geojson to DGGS, raster to DGGS, CSV to DGGS, compact, expand DGGS.


## Citations

If you find **vgrid** useful in your research, please consider citing the following paper to support my work. Thank you for your support.

## Demo

[Vgrid Homepage](https://vgrid.vn)
